==> modules_weight-8.x-1.1.tar.gz: modules_weight/src/Form/ModulesWeightAdminSettings.php <==
<?php

namespace Drupal\modules_weight\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class ModulesWeightAdminSettings.
 */
class ModulesWeightAdminSettings extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'modules_weight.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'modules_weight_admin_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('modules_weight.settings');
    $form['show_system_modules'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Show system modules'),
      '#description' => $this->t("Cautions: This module just display non-core modules by default, if you check this option it will cause unexpected behavior in the system, (USE IT ON YOUR OWN RISK) that's because displaying core modules in the Modules Weight form will reorder the system core modules execution even if you didn't change them and as you might notice all core modules has 0 as weight value by default."),
      '#default_value' => $config->get('show_system_modules'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    $this->config('modules_weight.settings')
      ->set('show_system_modules', $form_state->getValue('show_system_modules'))
      ->save();
  }

}

==> modules_weight-8.x-1.3.tar.gz: modules_weight/src/Form/ModulesWeightAdminSettings.php <==
<?php

namespace Drupal\modules_weight\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class ModulesWeightAdminSettings.
 */
class ModulesWeightAdminSettings extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'modules_weight.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'modules_weight_admin_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('modules_weight.settings');

    $form['show_system_modules'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Show system modules'),
      '#description' => $this->t("Cautions: This module just display non-core modules by default, if you check this option you will be able to change the core modules weight and as you might notice, all core modules has 0 as weight value by default."),
      '#default_value' => $config->get('show_system_modules'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);
    // Saving the module configuration.
    $this->config('modules_weight.settings')
      ->set('show_system_modules', $form_state->getValue('show_system_modules'))
      ->save();
  }

}
